---
title: Variables
description: Cheatsheet for universal variables (colors, sizes, etc.)
weight: 0
---

# Colors

  This is our current palette and these colors should be used per the rules outlined <a href="/styleguide/colors">here</a>.

## Grey Scale

  Use these for type, shading, depth, etc.

  `white` (#FFFFFF)</br>
  `$lightestGrey` (#E6E6E6)</br>
  `$lighterGrey` (#BCBCBC)</br>
  `$lightGrey` (#8B8B8B)</br>
  `$grey` (#313D3E)</br>
  `black` (#000000)</br>

## Primary Colors

  These are to be used as accents with `green` as the most prominent.

  `$green` (#00C7B7)</br>
  `$blue` (#4D9ABF)</br>
  `$gold` (#F6BC00)</br>
  `$orange` (#FE9D68)</br>

## Utility Colors

  Only to be used as an indicator (success/good or failure/bad).

  `$red` (#FB6D77)</br>
  `$lightGreen` (#75D472)</br>
  `$darkRed` (#FA3946)</br>
  `$darkGreen` (#00AD9F)</br>


# Typography Sizes

  Please try to limit font sizes to these. Of course, deviation is acceptable but we want to try to maintain heirarchy with these visual weights.

  `$xxlText` (36px)</br>
  `$xlText` (22px)</br>
  `$largeText` (18px)</br>
  `$mediumText` (16px)</br>
  `$smallText` (14px)</br>
  `$tinyText` (12px)</br>

# Typography Weights

  These variables are handy as they match the terminology used for 'Roboto' (our lead typeface).

  `$thin` (100)</br>
  `$light` (300)</br>
  `$regular` (400)</br>
  `$semibold` (500)</br>
  `$bold` (700)</br>
  `$black` (900)</br>

# Padding

  Please use these as often as possible. Of course, deviation is allowed and when positioning please consider actual pixels from things like x-height, etc. - not the top of the element as seen by the browser because they often have inherit padding that may not render the pixel-perfect design we strive for.

  `$micro` (8px)</br>
  `$tiny` (16px)</br>
  `$small` (24px)</br>
  `$medium` (40px)</br>
  `$large` (64px)</br>
  `$xl` (104px)</br>
  `$xxl` (168px)</br>

# Border Radius

  These are to be used for anything with a rounded edge - typically cards or buttons.

  `$smallRadius` (4px)</br>
  `$bigRadius` (10px)</br>

# Responsive Breakpoints

  To be used for breakpoint consistency. Of course, these are not limiting or prescriptive - just helpers.

  `$mobile` (480px)</br>
  `$tablet` (768px)</br>
  `$desktop` (960px)</br>
  `$display` (1200px)</br>

# Logo Versions

  These variables are to be used for image src's on `img` tags in html or `background`/`background-image` attributes in css. These are datauri's of the vector logo assets.

  <div class="logo" style="vertical-align: middle; padding-right: 24px;padding-top: 24px">light logo</div>
  `$lightLogo` (to be used on light backgrounds)</br>
  <div class="logo logomark" style="vertical-align: middle; padding-right: 24px;padding-top: 24px">logomark</div>
  `$colorLogomark` (to be used on monochromoatic backgrounds)</br>
  <div class="dark logo" style="vertical-align: middle; padding: 24px;margin: 24px 24px 24px 0; background-color: #222; background-position: center;">dark logo</div>
  `$darkLogo` (to be used on dark backgrounds)</br>